# carleslibs

Carles Mateo's Python Libraries v. 1.0.2

https://blog.carlesmateo.com

Install with:

```pip install carleslibs```

Packgades available:

DateTimeUtils()

FileUtils()

PythonUtils()

StringUtils()

SubProcessUtils()

